@@ -1,8 +1,6 @@
 # -*- coding: utf-8 -*-
 import itertools
-from functools import wraps
-
-from django import VERSION as django_version
+from distutils.version import LooseVersion
 
 import rest_framework
 
@@ -10,33 +8,14 @@ from rest_framework_extensions.key_constructor.constructors import (
     DefaultKeyConstructor,
     DefaultObjectKeyConstructor,
     DefaultListKeyConstructor,
+    DefaultAPIModelInstanceKeyConstructor,
+    DefaultAPIModelListKeyConstructor
 )
 from rest_framework_extensions.settings import extensions_api_settings
 
 
-def get_rest_framework_features():
-    return {
-        'router_trailing_slash': get_rest_framework_version() >= (2, 3, 6),
-        'allow_dot_in_lookup_regex_without_trailing_slash': get_rest_framework_version() >= (2, 3, 8),
-        'use_dot_in_lookup_regex_by_default': get_rest_framework_version() >= (2, 4, 0),
-        'max_paginate_by': get_rest_framework_version() >= (2, 3, 8),
-        'django_object_permissions_class': get_rest_framework_version() >= (2, 3, 8),
-        'write_only_fields': get_rest_framework_version() >= (2, 3, 11),
-        'uses_single_request_data_in_serializers': get_rest_framework_version() >= (3, 0),
-        'allows_to_send_custom_kwargs_for_saving_object_in_serializers': get_rest_framework_version() <= (3, 0),
-        'uses_single_request_data_in_serializers': get_rest_framework_version() >= (3, 0),
-    }
-
-
-def get_django_features():
-    # todo: test me
-    return {
-        'caches_singleton': django_version >= (1, 7, 0)
-    }
-
-
 def get_rest_framework_version():
-    return tuple(map(int, rest_framework.VERSION.split('.')))
+    return tuple(LooseVersion(rest_framework.VERSION).version)
 
 
 def flatten(list_of_lists):
@@ -86,3 +65,7 @@ default_list_cache_key_func = DefaultListKeyConstructor()
 default_etag_func = default_cache_key_func
 default_object_etag_func = default_object_cache_key_func
 default_list_etag_func = default_list_cache_key_func
+
+# API (object-centered) functions
+default_api_object_etag_func = DefaultAPIModelInstanceKeyConstructor()
+default_api_list_etag_func = DefaultAPIModelListKeyConstructor()
