@@ -5,12 +5,9 @@ from django.db import models
 class KeyConstructorUserProperty(models.Model):
     name = models.CharField(max_length=100)
 
-    class Meta:
-        app_label = 'tests_app'
-
 
 class KeyConstructorUserModel(models.Model):
-    property = models.ForeignKey(KeyConstructorUserProperty)
-
-    class Meta:
-        app_label = 'tests_app'
\ No newline at end of file
+    property = models.ForeignKey(
+        KeyConstructorUserProperty,
+        on_delete=models.CASCADE
+    )
