@@ -4,6 +4,3 @@ from django.db import models
 
 class CommentForListDestroyModelMixin(models.Model):
     email = models.EmailField()
-
-    class Meta:
-        app_label = 'tests_app'
\ No newline at end of file
