@@ -5,9 +5,6 @@ from django.db import models
 class CommentForListUpdateModelMixin(models.Model):
     email = models.EmailField()
 
-    class Meta:
-        app_label = 'tests_app'
-
 
 class UserForListUpdateModelMixin(models.Model):
     email = models.EmailField()
@@ -15,6 +12,3 @@ class UserForListUpdateModelMixin(models.Model):
     age = models.IntegerField()
     last_name = models.CharField(max_length=10)
     password = models.CharField(max_length=100)
-
-    class Meta:
-        app_label = 'tests_app'
\ No newline at end of file
