@@ -23,7 +23,7 @@ class CommentFilter(django_filters.FilterSet):
 class CommentViewSet(ListUpdateModelMixin, viewsets.ModelViewSet):
     queryset = Comment.objects.all()
     serializer_class = CommentSerializer
-    filter_backends = (filters.DjangoFilterBackend,)
+    filter_backends = (django_filters.rest_framework.DjangoFilterBackend,)
     filter_class = CommentFilter
 
 
