@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from mock import Mock
+from mock import PropertyMock
 
 from django.test import TestCase
 from django.utils.translation import override
@@ -7,7 +8,6 @@ from django.utils.translation import override
 from rest_framework import views
 from rest_framework.response import Response
 from rest_framework_extensions.test import APIRequestFactory
-from rest_framework_extensions.utils import get_django_features
 
 from rest_framework_extensions.key_constructor.bits import (
     KeyBitDictBase,
@@ -22,6 +22,8 @@ from rest_framework_extensions.key_constructor.bits import (
     PaginationKeyBit,
     ListSqlQueryKeyBit,
     RetrieveSqlQueryKeyBit,
+    ListModelKeyBit,
+    RetrieveModelKeyBit,
     ArgsKeyBit,
     KwargsKeyBit,
 )
@@ -243,7 +245,8 @@ class UserKeyBitTest(TestCase):
         }
         self.user = Mock()
         self.user.id = 123
-        self.user.is_authenticated = Mock(return_value=False)
+        self.is_authenticated = PropertyMock(return_value=False)
+        type(self.user).is_authenticated = self.is_authenticated
 
     def test_without_user_in_request(self):
         expected = u'anonymous'
@@ -256,7 +259,7 @@ class UserKeyBitTest(TestCase):
 
     def test_with_autenticated_user(self):
         self.kwargs['request'].user = self.user
-        self.kwargs['request'].user.is_authenticated.return_value = True
+        self.is_authenticated.return_value = True
         expected = u'123'
         self.assertEqual(UserKeyBit().get_data(**self.kwargs), expected)
 
@@ -388,9 +391,9 @@ class ListSqlQueryKeyBitTest(TestCase):
         self.kwargs['view_instance'].filter_queryset = lambda x: x.filter(is_active=True)
 
     def test_should_use_view__get_queryset__and_filter_it_with__filter_queryset(self):
-        expected = (u'SELECT "tests_app_bittestmodel"."id", "tests_app_bittestmodel"."is_active" '
-                    u'FROM "tests_app_bittestmodel" '
-                    u'WHERE "tests_app_bittestmodel"."is_active" = True{space}')
+        expected = (u'SELECT "unit_bittestmodel"."id", "unit_bittestmodel"."is_active" '
+                    u'FROM "unit_bittestmodel" '
+                    u'WHERE "unit_bittestmodel"."is_active" = True{space}')
 
         space = ''
         expected = expected.format(space=space)
@@ -408,6 +411,42 @@ class ListSqlQueryKeyBitTest(TestCase):
         self.assertEqual(response, None)
 
 
+class ListModelKeyBitTest(TestCase):
+    def setUp(self):
+        self.kwargs = {
+            'params': None,
+            'view_instance': Mock(),
+            'view_method': None,
+            'request': None,
+            'args': None,
+            'kwargs': None
+        }
+        self.kwargs['view_instance'].get_queryset = Mock(return_value=BitTestModel.objects.all())
+        self.kwargs['view_instance'].filter_queryset = lambda x: x.filter(is_active=True)
+
+    def test_should_use_view__get_queryset__and_filter_it_with__filter_queryset(self):
+        # create 4 models
+        BitTestModel.objects.create(is_active=True)
+        BitTestModel.objects.create(is_active=True)
+        BitTestModel.objects.create(is_active=True)
+        BitTestModel.objects.create(is_active=True)
+
+        expected = u"[(1, True), (2, True), (3, True), (4, True)]"
+
+        response = ListModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, expected)
+
+    def test_should_return_none_if_empty_queryset(self):
+        self.kwargs['view_instance'].filter_queryset = lambda x: x.none()
+        response = ListModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, None)
+
+    def test_should_return_none_if_empty_result_set_raised(self):
+        self.kwargs['view_instance'].filter_queryset = lambda x: x.filter(pk__in=[])
+        response = ListModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, None)
+
+
 class RetrieveSqlQueryKeyBitTest(TestCase):
     def setUp(self):
         self.kwargs = {
@@ -424,9 +463,9 @@ class RetrieveSqlQueryKeyBitTest(TestCase):
         self.kwargs['view_instance'].filter_queryset = lambda x: x.filter(is_active=True)
 
     def test_should_use_view__get_queryset__and_filter_it_with__filter_queryset__and_filter_by__lookup_field(self):
-        expected = (u'SELECT "tests_app_bittestmodel"."id", "tests_app_bittestmodel"."is_active" '
-                    u'FROM "tests_app_bittestmodel" '
-                    u'WHERE ("tests_app_bittestmodel"."is_active" = True {space}AND "tests_app_bittestmodel"."id" = 123{space})')
+        expected = (u'SELECT "unit_bittestmodel"."id", "unit_bittestmodel"."is_active" '
+                    u'FROM "unit_bittestmodel" '
+                    u'WHERE ("unit_bittestmodel"."is_active" = True {space}AND "unit_bittestmodel"."id" = 123{space})')
         space = ''
         expected = expected.format(space=space)
 
@@ -449,6 +488,46 @@ class RetrieveSqlQueryKeyBitTest(TestCase):
         self.assertEqual(response, None)
 
 
+class RetrieveModelKeyBitTest(TestCase):
+    def setUp(self):
+        self.kwargs = {
+            'params': None,
+            'view_instance': Mock(),
+            'view_method': None,
+            'request': None,
+            'args': None,
+            'kwargs': None
+        }
+        self.kwargs['view_instance'].kwargs = {'id': 123}
+        self.kwargs['view_instance'].lookup_field = 'id'
+        self.kwargs['view_instance'].get_queryset = Mock(return_value=BitTestModel.objects.all())
+        self.kwargs['view_instance'].filter_queryset = lambda x: x.filter(is_active=True)
+
+    def test_should_use_view__get_queryset__and_filter_it_with__filter_queryset__and_filter_by__lookup_field(self):
+        model = BitTestModel.objects.create(is_active=True)
+        self.kwargs['view_instance'].kwargs = {'id': model.id}
+
+        expected = u"[(%s, True)]" % model.id
+
+        response = RetrieveModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, expected)
+
+    def test_with_bad_lookup_value(self):
+        self.kwargs['view_instance'].kwargs = {'id': "I'm ganna hack u are!"}
+        response = RetrieveModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, None)
+
+    def test_should_return_none_if_empty_queryset(self):
+        self.kwargs['view_instance'].filter_queryset = lambda x: x.none()
+        response = RetrieveModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, None)
+
+    def test_should_return_none_if_empty_result_set_raised(self):
+        self.kwargs['view_instance'].filter_queryset = lambda x: x.filter(pk__in=[])
+        response = RetrieveModelKeyBit().get_data(**self.kwargs)
+        self.assertEqual(response, None)
+
+
 class ArgsKeyBitTest(TestCase):
     def setUp(self):
         self.test_args = ['abc', 'foobar', 'xyz']
